==> pyRestTable-2020.0.6rc2.tar.gz: pyRestTable-2020.0.6rc2/README.md <==
# pyRestTable

Format a nice table in reST (reStructuredText) from Python.

Each cell may have multiple lines, separated by a newline.
The content of each cell will be rendered as str(cell).
At present, *pyRestTable* only supports tables with content 
that does not span any cells (no rowspans or columnspans).

term | description
--- | ---
Install with conda | `conda install -c prjemian pyRestTable`
Install with pip | `pip install pyRestTable`
author | Pete R. Jemian
email | prjemian@gmail.com
copyright | 2014-2022, Pete R. Jemian
license | Creative Commons Attribution 4.0 International Public License (see *LICENSE.txt*)
docs | https://prjemian.github.io/pyRestTable
URL | https://github.com/prjemian/pyRestTable
TODO | https://github.com/prjemian/pyRestTable/issues
citations | [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.4265794.svg)](https://doi.org/10.5281/zenodo.4265794)
platforms | [![Anaconda-Server Badge](https://anaconda.org/prjemian/pyresttable/badges/platforms.svg)](https://anaconda.org/prjemian/pyresttable)
Python versions | [![PyPI versions](https://img.shields.io/pypi/pyversions/pyresttable.svg)](https://pypi.python.org/pypi/pyresttable)
conda | [![Anaconda-Server Badge](https://anaconda.org/prjemian/pyresttable/badges/installer/conda.svg)](https://conda.anaconda.org/prjemian)   [![Anaconda-Server Badge](https://anaconda.org/prjemian/pyresttable/badges/version.svg)](https://anaconda.org/prjemian/pyresttable)   [![Anaconda-Server Badge](https://anaconda.org/prjemian/pyresttable/badges/latest_release_date.svg)](https://anaconda.org/prjemian/pyresttable)
PyPI | [![PyPI Badge](https://img.shields.io/pypi/v/pyresttable.svg)](https://pypi.python.org/pypi/pyresttable)
build | ![Python Package using Conda](https://github.com/prjemian/pyRestTable/workflows/Python%20Package%20using%20Conda/badge.svg)
review | [![Codacy Badge](https://app.codacy.com/project/badge/Grade/a550dc5a2eb4494f9932bc6d60ddb5a7)](https://www.codacy.com/gh/prjemian/pyRestTable/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=prjemian/pyRestTable&amp;utm_campaign=Badge_Grade)   [![LGTM: Python](https://img.shields.io/lgtm/grade/python/g/prjemian/spec2nexus.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/spec2nexus/context:python)

==> pyRestTable-2020.0.7rc1.tar.gz: pyRestTable-2020.0.7rc1/README.md <==
# pyRestTable

Format a nice table in reST (reStructuredText) from Python.

Each cell may have multiple lines, separated by a newline.
The content of each cell will be rendered as str(cell).
At present, *pyRestTable* only supports tables with content 
that does not span any cells (no rowspans or columnspans).

term | description
--- | ---
Install with conda | `conda install -c conda-forge pyRestTable`
Install with pip | `pip install pyRestTable`
author | Pete R. Jemian
email | prjemian@gmail.com
copyright | 2014-2022, Pete R. Jemian
license | Creative Commons Attribution 4.0 International Public License (see *LICENSE.txt*)
docs | https://prjemian.github.io/pyRestTable
URL | https://github.com/prjemian/pyRestTable
TODO | https://github.com/prjemian/pyRestTable/issues
citations | [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.4265794.svg)](https://doi.org/10.5281/zenodo.4265794)
platforms | [![platforms](https://anaconda.org/conda-forge/pyresttable/badges/platforms.svg)](https://anaconda.org/conda-forge/pyresttable)
Python versions | [![PyPI](https://img.shields.io/pypi/pyversions/pyresttable.svg)](https://pypi.python.org/pypi/pyresttable)
conda | [![version](https://anaconda.org/conda-forge/pyresttable/badges/version.svg)](https://anaconda.org/conda-forge/pyresttable)   [![installer](https://anaconda.org/conda-forge/pyresttable/badges/installer/conda.svg)](https://conda.anaconda.org/prjemian)   [![release date](https://anaconda.org/conda-forge/pyresttable/badges/latest_release_date.svg)](https://anaconda.org/conda-forge/pyresttable)
PyPI | [![PyPI Badge](https://img.shields.io/pypi/v/pyresttable.svg)](https://pypi.python.org/pypi/pyresttable)
review | [![Codacy Badge](https://app.codacy.com/project/badge/Grade/a550dc5a2eb4494f9932bc6d60ddb5a7)](https://www.codacy.com/gh/prjemian/pyRestTable/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=prjemian/pyRestTable&amp;utm_campaign=Badge_Grade)   [![LGTM: Python](https://img.shields.io/lgtm/grade/python/g/prjemian/spec2nexus.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/spec2nexus/context:python)
